%%
%% This is file `l3backend-hitex.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% l3backend-basics.dtx  (with options: `package,hitex')
%% l3backend-color.dtx  (with options: `package,hitex')
%% l3backend-box.dtx  (with options: `package,hitex')
%% l3backend-draw.dtx  (with options: `package,hitex')
%% l3backend-graphics.dtx  (with options: `package,hitex')
%% l3backend-pdf.dtx  (with options: `package,hitex')
%% l3backend-pdfannot.dtx  (with options: `package,hitex')
%% l3backend-opacity.dtx  (with options: `package,hitex')
%% 
%% Copyright (C) 2019-2026 The LaTeX Project
%% 
%% It may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License (LPPL), either version 1.3c of
%% this license or (at your option) any later version.  The latest
%% version of this license is in the file:
%% 
%%    https://www.latex-project.org/lppl.txt
%% 
%% This file is part of the "l3backend bundle" (The Work in LPPL)
%% and all files in that bundle must be distributed together.
%% 
%% File: l3backend-basics.dtx
\ProvidesExplFile
  {l3backend-hitex.def}{2026-08-02}{}
  {L3 backend support: HiTeX}
\cs_if_exist:NTF \__kernel_dependency_version_check:nn
  {
    \__kernel_dependency_version_check:nn {2023-10-10}
      {l3backend-hitex.def}
  }
  {
    \cs_if_exist_use:cF { @latex@error } { \errmessage }
      {
        Mismatched~LaTeX~support~files~detected. \MessageBreak
        Loading~aborted!
      }
      { \use:c { @ehd } }
    \tex_endinput:D
  }
\cs_new_eq:NN \__kernel_backend_literal:e \tex_special:D
\cs_new_protected:Npn \__kernel_backend_literal:n #1
  { \__kernel_backend_literal:e { \exp_not:n {#1} } }
\cs_if_exist:NTF \@ifl@t@r
  {
    \@ifl@t@r \fmtversion { 2020-10-01 }
      {
        \cs_new_protected:Npn \__kernel_backend_first_shipout:n #1
          { \hook_gput_code:nnn { shipout / firstpage } { l3backend } {#1} }
      }
      { \cs_new_eq:NN \__kernel_backend_first_shipout:n \AtBeginDvi }
  }
  { \cs_new_eq:NN \__kernel_backend_first_shipout:n \use:n }
%% File: l3backend-color.dtx
%% File: l3backend-box.dtx
%% File: l3backend-draw.dtx
%% File: l3backend-graphics.dtx
%% File: l3backend-pdf.dtx
%% File: l3backend-pdfannot.dtx
\cs_new_eq:NN \__pdf_backend_annotation:nnnn \__pdfannot_backend_generic:nnnn
\cs_new_eq:NN \__pdf_backend_annotation_last: \__pdfannot_backend_last:
\clist_map_inline:nn
  {
    begin_goto:nnw ,
    begin_user:nnw ,
    begin:nnnw     ,
    end:           ,
    last:          ,
    margin:n
  }
  { \cs_new_eq:cc { __pdf_backend_link_ #1 } { __pdfannot_backend_link_ #1 } }
%% File: l3backend-opacity.dtx
%% 
%%
%% End of file `l3backend-hitex.def'.
